DebounceDurations class
A collection of commonly used debounce durations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- long → const Duration
- Long debounce for expensive operations (1000ms)
- medium → const Duration
- Medium debounce for notifications (500ms)
- short → const Duration
- Short debounce for user interactions (250ms)
- veryLong → const Duration
- Very long debounce for rare operations (2000ms)
- veryShort → const Duration
- Very short debounce for rapid interactions (100ms)