dispose method
void
dispose()
Disposes of the debouncer and cancels any pending actions.
Call this when you're done with the debouncer to prevent memory leaks.
Implementation
void dispose() {
cancel();
}
Disposes of the debouncer and cancels any pending actions.
Call this when you're done with the debouncer to prevent memory leaks.
void dispose() {
cancel();
}