resetLastMessageId method
void
resetLastMessageId()
Resets the last message ID, allowing the next message to be processed regardless of its ID.
Implementation
void resetLastMessageId() {
_lastMessageId = null;
}
Resets the last message ID, allowing the next message to be processed regardless of its ID.
void resetLastMessageId() {
_lastMessageId = null;
}