RxList<T> constructor
RxList<T> ([
- List<
T> ? initial
Creates a new reactive list with the initial value.
Implementation
RxList([List<T>? initial]) : super(initial ?? <T>[]);
Creates a new reactive list with the initial value.
RxList([List<T>? initial]) : super(initial ?? <T>[]);