firstOrNull property
T?
get
firstOrNull
Returns the first item in the list, or null if empty.
Implementation
T? get firstOrNull => value.isEmpty ? null : value.first;
Returns the first item in the list, or null if empty.
T? get firstOrNull => value.isEmpty ? null : value.first;