RxString constructor
RxString(
- String value
Creates a new reactive string with the initial value.
Implementation
RxString(super.value);
Creates a new reactive string with the initial value.
RxString(super.value);